@@ -41,7 +41,12 @@ class ImageAccessory(Accessory):
         self.alt_text: str = alt_text
 
     def serialize(self) -> dict:
-        return super().serialize() | {
-            "image_url": self.image_url,
-            "alt_text": self.alt_text,
-        }
+        serialized = super().serialize()
+        serialized.update(
+            {
+                "image_url": self.image_url,
+                "alt_text": self.alt_text,
+            }
+        )
+
+        return serialized
